@@ -2,7 +2,8 @@
 use strict;
 
 use Chart::Clicker;
-use Chart::Clicker::Renderer::Point;
+use Chart::Clicker::Renderer::Line;
+use Chart::Clicker::Data::Marker;
 
 my $cc = Chart::Clicker->new(width => 500, height => 250);
 
@@ -28,11 +29,19 @@ foreach my $d (@bw3) {
 
 my $def = $cc->get_context('default');
 
-my $ren = Chart::Clicker::Renderer::Point->new;
+my $ren = Chart::Clicker::Renderer::Line->new;
 $cc->get_context('default')->renderer($ren);
-$def->range_axis->skip_range(Chart::Clicker::Data::Range->new(lower => 20, upper => 95));
+$def->range_axis->skip_range(Chart::Clicker::Data::Range->new(lower => 20, upper => 70));
+$def->domain_axis->tick_values([qw(10 20 30 40 50 60 70 80 90 100)]);
 $def->range_axis->format('%d');
 $def->domain_axis->tick_values([qw(2 4 6 8 10)]);
 $def->domain_axis->format('%d');
 
+my $skip_marker = Chart::Clicker::Data::Marker->new(value => 19.9, value2 => 70.1);
+$skip_marker->color(
+    Graphics::Color::RGB->new(red => 0, green => 0, blue => 0)
+);
+$def->add_marker($skip_marker);
+
+
 $cc->write_output('foo.png');
