@@ -1,6 +1,6 @@
 package Chart::Clicker::Renderer::Bar;
 {
-  $Chart::Clicker::Renderer::Bar::VERSION = '2.77';
+  $Chart::Clicker::Renderer::Bar::VERSION = '2.78';
 }
 use Moose;
 
@@ -196,7 +196,7 @@ Chart::Clicker::Renderer::Bar - Bar renderer
 
 =head1 VERSION
 
-version 2.77
+version 2.78
 
 =head1 SYNOPSIS
 
@@ -232,7 +232,7 @@ multiple series.
 
 =head2 brush
 
-Set/Get the Brush to use around each bar.
+Set/Get the L<brush|Graphics::Primitive::Brush> to use around each bar.
 
 =head2 opacity
 
