@@ -1,6 +1,6 @@
 package Chart::Clicker::Renderer::Pie;
 {
-  $Chart::Clicker::Renderer::Pie::VERSION = '2.77';
+  $Chart::Clicker::Renderer::Pie::VERSION = '2.78';
 }
 use Moose;
 
@@ -180,7 +180,7 @@ Chart::Clicker::Renderer::Pie - Pie renderer
 
 =head1 VERSION
 
-version 2.77
+version 2.78
 
 =head1 SYNOPSIS
 
@@ -216,15 +216,15 @@ The keys are discarded and a pie chart will be drawn with $series' slice at
 
 =head2 border_color
 
-Set/Get the Color to use for the border.
+Set/Get the L<color|Graphics::Color::RGB> to use for the border.
 
 =head2 brush
 
-Set/Get a Brush to be used for the pie's border.
+Set/Get a L<brush|Graphics::Primitive::Brush> to be used for the pie's border.
 
 =head2 gradient_color
 
-If supplied, specifies a color to mix with each slice's color for use as a
+If supplied, specifies a L<color|Graphics::Color::RGB> to mix with each slice's color for use as a
 radial gradient.  The best results are usually gotten from mixing with a
 white or black and manipulating the alpha, like so:
 
